Documentation
¶
Index ¶
- Constants
- func Bool(fd protoreflect.FieldDescriptor) bool
- func Bytes(fd protoreflect.FieldDescriptor) []byte
- func Enum(fd protoreflect.FieldDescriptor) protoreflect.EnumNumber
- func Fixed32(fd protoreflect.FieldDescriptor) uint32
- func Fixed64(fd protoreflect.FieldDescriptor) uint64
- func Float32(fd protoreflect.FieldDescriptor) float32
- func Float64(fd protoreflect.FieldDescriptor) float64
- func GoogleDuration(fd protoreflect.FieldDescriptor) *durationpb.Duration
- func GoogleTimestamp(fd protoreflect.FieldDescriptor) *timestamppb.Timestamp
- func GoogleValue(fd protoreflect.FieldDescriptor, st state) *structpb.Value
- func Int32(fd protoreflect.FieldDescriptor) int32
- func Int64(fd protoreflect.FieldDescriptor) int64
- func NewMessage(md protoreflect.MessageDescriptor) *dynamicpb.Message
- func SFixed32(fd protoreflect.FieldDescriptor) int32
- func SFixed64(fd protoreflect.FieldDescriptor) int64
- func SInt32(fd protoreflect.FieldDescriptor) int32
- func SInt64(fd protoreflect.FieldDescriptor) int64
- func SetDataOnMessage(msg *dynamicpb.Message)
- func String(fd protoreflect.FieldDescriptor) string
- func UInt32(fd protoreflect.FieldDescriptor) uint32
- func UInt64(fd protoreflect.FieldDescriptor) uint64
Constants ¶
const MaxNestedDepth = 20
Variables ¶
This section is empty.
Functions ¶
func Bool ¶ added in v0.0.9
func Bool(fd protoreflect.FieldDescriptor) bool
Bool returns a fake boolean value given a field descriptor.
func Bytes ¶ added in v0.0.9
func Bytes(fd protoreflect.FieldDescriptor) []byte
Bytes returns a fake []byte value given a field descriptor.
func Enum ¶ added in v0.0.9
func Enum(fd protoreflect.FieldDescriptor) protoreflect.EnumNumber
Enum returns a fake enum value given a field descriptor.
func Fixed32 ¶ added in v0.0.9
func Fixed32(fd protoreflect.FieldDescriptor) uint32
Fixed32 returns a fake fixed32 value given a field descriptor.
func Fixed64 ¶ added in v0.0.9
func Fixed64(fd protoreflect.FieldDescriptor) uint64
Fixed64 returns a fake fixed64 value given a field descriptor.
func Float32 ¶ added in v0.0.9
func Float32(fd protoreflect.FieldDescriptor) float32
Float32 returns a fake float32 value given a field descriptor.
func Float64 ¶ added in v0.0.9
func Float64(fd protoreflect.FieldDescriptor) float64
Float64 returns a fake float64 value given a field descriptor.
func GoogleDuration ¶ added in v0.0.9
func GoogleDuration(fd protoreflect.FieldDescriptor) *durationpb.Duration
GoogleDuration generates a random google.protobuf.Duration value.
func GoogleTimestamp ¶ added in v0.0.9
func GoogleTimestamp(fd protoreflect.FieldDescriptor) *timestamppb.Timestamp
GoogleTimestamp generates a random google.protobuf.Timestamp value.
func GoogleValue ¶ added in v0.0.9
func GoogleValue(fd protoreflect.FieldDescriptor, st state) *structpb.Value
func Int32 ¶ added in v0.0.9
func Int32(fd protoreflect.FieldDescriptor) int32
Int32 returns a fake int32 value given a field descriptor.
func Int64 ¶ added in v0.0.9
func Int64(fd protoreflect.FieldDescriptor) int64
Int64 returns a fake int64 value given a field descriptor.
func NewMessage ¶ added in v0.0.10
func NewMessage(md protoreflect.MessageDescriptor) *dynamicpb.Message
NewMessage creates a new message populated with fake data given a protoreflect.MessageDescriptor
func SFixed32 ¶ added in v0.0.9
func SFixed32(fd protoreflect.FieldDescriptor) int32
SFixed32 returns a fake sfixedint32 value given a field descriptor.
func SFixed64 ¶ added in v0.0.9
func SFixed64(fd protoreflect.FieldDescriptor) int64
SFixed64 returns a fake sfixed64 value given a field descriptor.
func SInt32 ¶ added in v0.0.9
func SInt32(fd protoreflect.FieldDescriptor) int32
SInt32 returns a fake sint32 value given a field descriptor.
func SInt64 ¶ added in v0.0.9
func SInt64(fd protoreflect.FieldDescriptor) int64
SInt64 returns a fake sint64 value given a field descriptor.
func SetDataOnMessage ¶ added in v0.0.4
SetDataOnMessage generates fake data given a *dynamicpb.Message and sets the field values.
func String ¶ added in v0.0.9
func String(fd protoreflect.FieldDescriptor) string
String returns a fake string value given a field descriptor.
func UInt32 ¶ added in v0.0.9
func UInt32(fd protoreflect.FieldDescriptor) uint32
UInt32 returns a fake uint32 value given a field descriptor.
func UInt64 ¶ added in v0.0.9
func UInt64(fd protoreflect.FieldDescriptor) uint64
UInt64 returns a fake uint64 value given a field descriptor.
Types ¶
This section is empty.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
fauxrpc
command
|
|
|
example
|
|
|
generated-faux-server
module
|
|
|
generated-mocks
module
|
|
|
private
|
|
|
testcontainers
module
|