Documentation
¶
Index ¶
- Constants
- Variables
- type AddStubsRequest
- type AddStubsRequest_builder
- type AddStubsResponse
- type AddStubsResponse_builder
- type CELGenerate
- func (x *CELGenerate) ClearEnabled()
- func (x *CELGenerate) GetEnabled() bool
- func (x *CELGenerate) HasEnabled() bool
- func (*CELGenerate) ProtoMessage()
- func (x *CELGenerate) ProtoReflect() protoreflect.Message
- func (x *CELGenerate) Reset()
- func (x *CELGenerate) SetEnabled(v bool)
- func (x *CELGenerate) String() string
- type CELGenerate_builder
- type Error
- func (x *Error) ClearCode()
- func (x *Error) ClearMessage()
- func (x *Error) GetCode() ErrorCode
- func (x *Error) GetDetails() []*anypb.Any
- func (x *Error) GetMessage() string
- func (x *Error) HasCode() bool
- func (x *Error) HasMessage() bool
- func (*Error) ProtoMessage()
- func (x *Error) ProtoReflect() protoreflect.Message
- func (x *Error) Reset()
- func (x *Error) SetCode(v ErrorCode)
- func (x *Error) SetDetails(v []*anypb.Any)
- func (x *Error) SetMessage(v string)
- func (x *Error) String() string
- type ErrorCode
- type Error_builder
- type ListStubsRequest
- func (x *ListStubsRequest) ClearStubRef()
- func (x *ListStubsRequest) GetStubRef() *StubRef
- func (x *ListStubsRequest) HasStubRef() bool
- func (*ListStubsRequest) ProtoMessage()
- func (x *ListStubsRequest) ProtoReflect() protoreflect.Message
- func (x *ListStubsRequest) Reset()
- func (x *ListStubsRequest) SetStubRef(v *StubRef)
- func (x *ListStubsRequest) String() string
- type ListStubsRequest_builder
- type ListStubsResponse
- type ListStubsResponse_builder
- type RemoveAllStubsRequest
- type RemoveAllStubsRequest_builder
- type RemoveAllStubsResponse
- type RemoveAllStubsResponse_builder
- type RemoveStubsRequest
- type RemoveStubsRequest_builder
- type RemoveStubsResponse
- type RemoveStubsResponse_builder
- type Stream
- func (x *Stream) ClearDoneAfter()
- func (x *Stream) ClearRepeated()
- func (x *Stream) GetDoneAfter() *durationpb.Duration
- func (x *Stream) GetItems() []*StreamItem
- func (x *Stream) GetRepeated() bool
- func (x *Stream) HasDoneAfter() bool
- func (x *Stream) HasRepeated() bool
- func (*Stream) ProtoMessage()
- func (x *Stream) ProtoReflect() protoreflect.Message
- func (x *Stream) Reset()
- func (x *Stream) SetDoneAfter(v *durationpb.Duration)
- func (x *Stream) SetItems(v []*StreamItem)
- func (x *Stream) SetRepeated(v bool)
- func (x *Stream) String() string
- type StreamItem
- func (x *StreamItem) ClearCelContent()
- func (x *StreamItem) ClearContent()
- func (x *StreamItem) ClearDelay()
- func (x *StreamItem) ClearError()
- func (x *StreamItem) ClearJson()
- func (x *StreamItem) ClearProto()
- func (x *StreamItem) GetCelContent() string
- func (x *StreamItem) GetDelay() *durationpb.Duration
- func (x *StreamItem) GetError() *Error
- func (x *StreamItem) GetJson() string
- func (x *StreamItem) GetProto() []byte
- func (x *StreamItem) HasCelContent() bool
- func (x *StreamItem) HasContent() bool
- func (x *StreamItem) HasDelay() bool
- func (x *StreamItem) HasError() bool
- func (x *StreamItem) HasJson() bool
- func (x *StreamItem) HasProto() bool
- func (*StreamItem) ProtoMessage()
- func (x *StreamItem) ProtoReflect() protoreflect.Message
- func (x *StreamItem) Reset()
- func (x *StreamItem) SetCelContent(v string)
- func (x *StreamItem) SetDelay(v *durationpb.Duration)
- func (x *StreamItem) SetError(v *Error)
- func (x *StreamItem) SetJson(v string)
- func (x *StreamItem) SetProto(v []byte)
- func (x *StreamItem) String() string
- func (x *StreamItem) WhichContent() case_StreamItem_Content
- type StreamItem_builder
- type Stream_builder
- type Stub
- func (x *Stub) ClearActiveIf()
- func (x *Stub) ClearCelContent()
- func (x *Stub) ClearContent()
- func (x *Stub) ClearError()
- func (x *Stub) ClearJson()
- func (x *Stub) ClearPriority()
- func (x *Stub) ClearProto()
- func (x *Stub) ClearRef()
- func (x *Stub) ClearStream()
- func (x *Stub) GetActiveIf() string
- func (x *Stub) GetCelContent() string
- func (x *Stub) GetError() *Error
- func (x *Stub) GetJson() string
- func (x *Stub) GetPriority() int32
- func (x *Stub) GetProto() []byte
- func (x *Stub) GetRef() *StubRef
- func (x *Stub) GetStream() *Stream
- func (x *Stub) HasActiveIf() bool
- func (x *Stub) HasCelContent() bool
- func (x *Stub) HasContent() bool
- func (x *Stub) HasError() bool
- func (x *Stub) HasJson() bool
- func (x *Stub) HasPriority() bool
- func (x *Stub) HasProto() bool
- func (x *Stub) HasRef() bool
- func (x *Stub) HasStream() bool
- func (*Stub) ProtoMessage()
- func (x *Stub) ProtoReflect() protoreflect.Message
- func (x *Stub) Reset()
- func (x *Stub) SetActiveIf(v string)
- func (x *Stub) SetCelContent(v string)
- func (x *Stub) SetError(v *Error)
- func (x *Stub) SetJson(v string)
- func (x *Stub) SetPriority(v int32)
- func (x *Stub) SetProto(v []byte)
- func (x *Stub) SetRef(v *StubRef)
- func (x *Stub) SetStream(v *Stream)
- func (x *Stub) String() string
- func (x *Stub) WhichContent() case_Stub_Content
- type StubRef
- func (x *StubRef) ClearId()
- func (x *StubRef) ClearTarget()
- func (x *StubRef) GetId() string
- func (x *StubRef) GetTarget() string
- func (x *StubRef) HasId() bool
- func (x *StubRef) HasTarget() bool
- func (*StubRef) ProtoMessage()
- func (x *StubRef) ProtoReflect() protoreflect.Message
- func (x *StubRef) Reset()
- func (x *StubRef) SetId(v string)
- func (x *StubRef) SetTarget(v string)
- func (x *StubRef) String() string
- type StubRef_builder
- type Stub_builder
Constants ¶
const StreamItem_Content_not_set_case case_StreamItem_Content = 0
const StreamItem_Error_case case_StreamItem_Content = 3
const StreamItem_Json_case case_StreamItem_Content = 2
const StreamItem_Proto_case case_StreamItem_Content = 1
const Stub_Content_not_set_case case_Stub_Content = 0
const Stub_Error_case case_Stub_Content = 4
const Stub_Json_case case_Stub_Content = 3
const Stub_Proto_case case_Stub_Content = 2
Variables ¶
var ( ErrorCode_name = map[int32]string{ 0: "ERROR_CODE_OK_UNSPECIFIED", 1: "ERROR_CODE_CANCELLED", 2: "ERROR_CODE_UNKNOWN", 3: "ERROR_CODE_INVALID_ARGUMENT", 4: "ERROR_CODE_DEADLINE_EXCEEDED", 5: "ERROR_CODE_NOT_FOUND", 6: "ERROR_CODE_ALREADY_EXISTS", 7: "ERROR_CODE_PERMISSION_DENIED", 8: "ERROR_CODE_RESOURCE_EXHAUSTED", 9: "ERROR_CODE_FAILED_PRECONDITION", 10: "ERROR_CODE_ABORTED", 11: "ERROR_CODE_OUT_OF_RANGE", 12: "ERROR_CODE_UNIMPLEMENTED", 13: "ERROR_CODE_INTERNAL", 14: "ERROR_CODE_UNAVAILABLE", 15: "ERROR_CODE_DATA_LOSS", 16: "ERROR_CODE_UNAUTHENTICATED", } ErrorCode_value = map[string]int32{ "ERROR_CODE_OK_UNSPECIFIED": 0, "ERROR_CODE_CANCELLED": 1, "ERROR_CODE_UNKNOWN": 2, "ERROR_CODE_INVALID_ARGUMENT": 3, "ERROR_CODE_DEADLINE_EXCEEDED": 4, "ERROR_CODE_NOT_FOUND": 5, "ERROR_CODE_ALREADY_EXISTS": 6, "ERROR_CODE_PERMISSION_DENIED": 7, "ERROR_CODE_RESOURCE_EXHAUSTED": 8, "ERROR_CODE_FAILED_PRECONDITION": 9, "ERROR_CODE_ABORTED": 10, "ERROR_CODE_OUT_OF_RANGE": 11, "ERROR_CODE_UNIMPLEMENTED": 12, "ERROR_CODE_INTERNAL": 13, "ERROR_CODE_UNAVAILABLE": 14, "ERROR_CODE_DATA_LOSS": 15, "ERROR_CODE_UNAUTHENTICATED": 16, } )
Enum value maps for ErrorCode.
var File_stubs_v1_stubs_proto protoreflect.FileDescriptor
var File_stubs_v1_stubs_service_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AddStubsRequest ¶
type AddStubsRequest struct {
// contains filtered or unexported fields
}
func (*AddStubsRequest) GetStubs ¶
func (x *AddStubsRequest) GetStubs() []*Stub
func (*AddStubsRequest) ProtoMessage ¶
func (*AddStubsRequest) ProtoMessage()
func (*AddStubsRequest) ProtoReflect ¶
func (x *AddStubsRequest) ProtoReflect() protoreflect.Message
func (*AddStubsRequest) Reset ¶
func (x *AddStubsRequest) Reset()
func (*AddStubsRequest) SetStubs ¶
func (x *AddStubsRequest) SetStubs(v []*Stub)
func (*AddStubsRequest) String ¶
func (x *AddStubsRequest) String() string
type AddStubsRequest_builder ¶
type AddStubsRequest_builder struct {
Stubs []*Stub
// contains filtered or unexported fields
}
func (AddStubsRequest_builder) Build ¶
func (b0 AddStubsRequest_builder) Build() *AddStubsRequest
type AddStubsResponse ¶
type AddStubsResponse struct {
// contains filtered or unexported fields
}
func (*AddStubsResponse) GetStubs ¶
func (x *AddStubsResponse) GetStubs() []*Stub
func (*AddStubsResponse) ProtoMessage ¶
func (*AddStubsResponse) ProtoMessage()
func (*AddStubsResponse) ProtoReflect ¶
func (x *AddStubsResponse) ProtoReflect() protoreflect.Message
func (*AddStubsResponse) Reset ¶
func (x *AddStubsResponse) Reset()
func (*AddStubsResponse) SetStubs ¶
func (x *AddStubsResponse) SetStubs(v []*Stub)
func (*AddStubsResponse) String ¶
func (x *AddStubsResponse) String() string
type AddStubsResponse_builder ¶
type AddStubsResponse_builder struct {
Stubs []*Stub
// contains filtered or unexported fields
}
func (AddStubsResponse_builder) Build ¶
func (b0 AddStubsResponse_builder) Build() *AddStubsResponse
type CELGenerate ¶
type CELGenerate struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*CELGenerate) ClearEnabled ¶
func (x *CELGenerate) ClearEnabled()
func (*CELGenerate) GetEnabled ¶
func (x *CELGenerate) GetEnabled() bool
func (*CELGenerate) HasEnabled ¶
func (x *CELGenerate) HasEnabled() bool
func (*CELGenerate) ProtoMessage ¶
func (*CELGenerate) ProtoMessage()
func (*CELGenerate) ProtoReflect ¶
func (x *CELGenerate) ProtoReflect() protoreflect.Message
func (*CELGenerate) Reset ¶
func (x *CELGenerate) Reset()
func (*CELGenerate) SetEnabled ¶
func (x *CELGenerate) SetEnabled(v bool)
func (*CELGenerate) String ¶
func (x *CELGenerate) String() string
type CELGenerate_builder ¶
type CELGenerate_builder struct {
Enabled *bool
// contains filtered or unexported fields
}
func (CELGenerate_builder) Build ¶
func (b0 CELGenerate_builder) Build() *CELGenerate
type Error ¶
type Error struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*Error) ClearMessage ¶
func (x *Error) ClearMessage()
func (*Error) GetDetails ¶
func (*Error) GetMessage ¶
func (*Error) HasMessage ¶
func (*Error) ProtoMessage ¶
func (*Error) ProtoMessage()
func (*Error) ProtoReflect ¶
func (x *Error) ProtoReflect() protoreflect.Message
func (*Error) SetDetails ¶
func (*Error) SetMessage ¶
type ErrorCode ¶
type ErrorCode int32
const ( ErrorCode_ERROR_CODE_OK_UNSPECIFIED ErrorCode = 0 ErrorCode_ERROR_CODE_CANCELLED ErrorCode = 1 ErrorCode_ERROR_CODE_UNKNOWN ErrorCode = 2 ErrorCode_ERROR_CODE_INVALID_ARGUMENT ErrorCode = 3 ErrorCode_ERROR_CODE_DEADLINE_EXCEEDED ErrorCode = 4 ErrorCode_ERROR_CODE_NOT_FOUND ErrorCode = 5 ErrorCode_ERROR_CODE_ALREADY_EXISTS ErrorCode = 6 ErrorCode_ERROR_CODE_PERMISSION_DENIED ErrorCode = 7 ErrorCode_ERROR_CODE_RESOURCE_EXHAUSTED ErrorCode = 8 ErrorCode_ERROR_CODE_FAILED_PRECONDITION ErrorCode = 9 ErrorCode_ERROR_CODE_ABORTED ErrorCode = 10 ErrorCode_ERROR_CODE_OUT_OF_RANGE ErrorCode = 11 ErrorCode_ERROR_CODE_UNIMPLEMENTED ErrorCode = 12 ErrorCode_ERROR_CODE_INTERNAL ErrorCode = 13 ErrorCode_ERROR_CODE_UNAVAILABLE ErrorCode = 14 ErrorCode_ERROR_CODE_DATA_LOSS ErrorCode = 15 ErrorCode_ERROR_CODE_UNAUTHENTICATED ErrorCode = 16 )
func (ErrorCode) Descriptor ¶
func (ErrorCode) Descriptor() protoreflect.EnumDescriptor
func (ErrorCode) Number ¶
func (x ErrorCode) Number() protoreflect.EnumNumber
func (ErrorCode) Type ¶
func (ErrorCode) Type() protoreflect.EnumType
type Error_builder ¶
type Error_builder struct {
Code *ErrorCode
Message *string
Details []*anypb.Any
// contains filtered or unexported fields
}
func (Error_builder) Build ¶
func (b0 Error_builder) Build() *Error
type ListStubsRequest ¶
type ListStubsRequest struct {
// contains filtered or unexported fields
}
func (*ListStubsRequest) ClearStubRef ¶
func (x *ListStubsRequest) ClearStubRef()
func (*ListStubsRequest) GetStubRef ¶
func (x *ListStubsRequest) GetStubRef() *StubRef
func (*ListStubsRequest) HasStubRef ¶
func (x *ListStubsRequest) HasStubRef() bool
func (*ListStubsRequest) ProtoMessage ¶
func (*ListStubsRequest) ProtoMessage()
func (*ListStubsRequest) ProtoReflect ¶
func (x *ListStubsRequest) ProtoReflect() protoreflect.Message
func (*ListStubsRequest) Reset ¶
func (x *ListStubsRequest) Reset()
func (*ListStubsRequest) SetStubRef ¶
func (x *ListStubsRequest) SetStubRef(v *StubRef)
func (*ListStubsRequest) String ¶
func (x *ListStubsRequest) String() string
type ListStubsRequest_builder ¶
type ListStubsRequest_builder struct {
StubRef *StubRef
// contains filtered or unexported fields
}
func (ListStubsRequest_builder) Build ¶
func (b0 ListStubsRequest_builder) Build() *ListStubsRequest
type ListStubsResponse ¶
type ListStubsResponse struct {
// contains filtered or unexported fields
}
func (*ListStubsResponse) GetStubs ¶
func (x *ListStubsResponse) GetStubs() []*Stub
func (*ListStubsResponse) ProtoMessage ¶
func (*ListStubsResponse) ProtoMessage()
func (*ListStubsResponse) ProtoReflect ¶
func (x *ListStubsResponse) ProtoReflect() protoreflect.Message
func (*ListStubsResponse) Reset ¶
func (x *ListStubsResponse) Reset()
func (*ListStubsResponse) SetStubs ¶
func (x *ListStubsResponse) SetStubs(v []*Stub)
func (*ListStubsResponse) String ¶
func (x *ListStubsResponse) String() string
type ListStubsResponse_builder ¶
type ListStubsResponse_builder struct {
Stubs []*Stub
// contains filtered or unexported fields
}
func (ListStubsResponse_builder) Build ¶
func (b0 ListStubsResponse_builder) Build() *ListStubsResponse
type RemoveAllStubsRequest ¶
type RemoveAllStubsRequest struct {
// contains filtered or unexported fields
}
func (*RemoveAllStubsRequest) ProtoMessage ¶
func (*RemoveAllStubsRequest) ProtoMessage()
func (*RemoveAllStubsRequest) ProtoReflect ¶
func (x *RemoveAllStubsRequest) ProtoReflect() protoreflect.Message
func (*RemoveAllStubsRequest) Reset ¶
func (x *RemoveAllStubsRequest) Reset()
func (*RemoveAllStubsRequest) String ¶
func (x *RemoveAllStubsRequest) String() string
type RemoveAllStubsRequest_builder ¶
type RemoveAllStubsRequest_builder struct {
// contains filtered or unexported fields
}
func (RemoveAllStubsRequest_builder) Build ¶
func (b0 RemoveAllStubsRequest_builder) Build() *RemoveAllStubsRequest
type RemoveAllStubsResponse ¶
type RemoveAllStubsResponse struct {
// contains filtered or unexported fields
}
func (*RemoveAllStubsResponse) ProtoMessage ¶
func (*RemoveAllStubsResponse) ProtoMessage()
func (*RemoveAllStubsResponse) ProtoReflect ¶
func (x *RemoveAllStubsResponse) ProtoReflect() protoreflect.Message
func (*RemoveAllStubsResponse) Reset ¶
func (x *RemoveAllStubsResponse) Reset()
func (*RemoveAllStubsResponse) String ¶
func (x *RemoveAllStubsResponse) String() string
type RemoveAllStubsResponse_builder ¶
type RemoveAllStubsResponse_builder struct {
// contains filtered or unexported fields
}
func (RemoveAllStubsResponse_builder) Build ¶
func (b0 RemoveAllStubsResponse_builder) Build() *RemoveAllStubsResponse
type RemoveStubsRequest ¶
type RemoveStubsRequest struct {
// contains filtered or unexported fields
}
func (*RemoveStubsRequest) GetStubRefs ¶
func (x *RemoveStubsRequest) GetStubRefs() []*StubRef
func (*RemoveStubsRequest) ProtoMessage ¶
func (*RemoveStubsRequest) ProtoMessage()
func (*RemoveStubsRequest) ProtoReflect ¶
func (x *RemoveStubsRequest) ProtoReflect() protoreflect.Message
func (*RemoveStubsRequest) Reset ¶
func (x *RemoveStubsRequest) Reset()
func (*RemoveStubsRequest) SetStubRefs ¶
func (x *RemoveStubsRequest) SetStubRefs(v []*StubRef)
func (*RemoveStubsRequest) String ¶
func (x *RemoveStubsRequest) String() string
type RemoveStubsRequest_builder ¶
type RemoveStubsRequest_builder struct {
StubRefs []*StubRef
// contains filtered or unexported fields
}
func (RemoveStubsRequest_builder) Build ¶
func (b0 RemoveStubsRequest_builder) Build() *RemoveStubsRequest
type RemoveStubsResponse ¶
type RemoveStubsResponse struct {
// contains filtered or unexported fields
}
func (*RemoveStubsResponse) ProtoMessage ¶
func (*RemoveStubsResponse) ProtoMessage()
func (*RemoveStubsResponse) ProtoReflect ¶
func (x *RemoveStubsResponse) ProtoReflect() protoreflect.Message
func (*RemoveStubsResponse) Reset ¶
func (x *RemoveStubsResponse) Reset()
func (*RemoveStubsResponse) String ¶
func (x *RemoveStubsResponse) String() string
type RemoveStubsResponse_builder ¶
type RemoveStubsResponse_builder struct {
// contains filtered or unexported fields
}
func (RemoveStubsResponse_builder) Build ¶
func (b0 RemoveStubsResponse_builder) Build() *RemoveStubsResponse
type Stream ¶ added in v0.18.0
type Stream struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*Stream) ClearDoneAfter ¶ added in v0.18.0
func (x *Stream) ClearDoneAfter()
func (*Stream) ClearRepeated ¶ added in v0.18.0
func (x *Stream) ClearRepeated()
func (*Stream) GetDoneAfter ¶ added in v0.18.0
func (x *Stream) GetDoneAfter() *durationpb.Duration
func (*Stream) GetItems ¶ added in v0.18.0
func (x *Stream) GetItems() []*StreamItem
func (*Stream) GetRepeated ¶ added in v0.18.0
func (*Stream) HasDoneAfter ¶ added in v0.18.0
func (*Stream) HasRepeated ¶ added in v0.18.0
func (*Stream) ProtoMessage ¶ added in v0.18.0
func (*Stream) ProtoMessage()
func (*Stream) ProtoReflect ¶ added in v0.18.0
func (x *Stream) ProtoReflect() protoreflect.Message
func (*Stream) SetDoneAfter ¶ added in v0.18.0
func (x *Stream) SetDoneAfter(v *durationpb.Duration)
func (*Stream) SetItems ¶ added in v0.18.0
func (x *Stream) SetItems(v []*StreamItem)
func (*Stream) SetRepeated ¶ added in v0.18.0
type StreamItem ¶ added in v0.18.0
type StreamItem struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*StreamItem) ClearCelContent ¶ added in v0.18.0
func (x *StreamItem) ClearCelContent()
func (*StreamItem) ClearContent ¶ added in v0.18.0
func (x *StreamItem) ClearContent()
func (*StreamItem) ClearDelay ¶ added in v0.18.0
func (x *StreamItem) ClearDelay()
func (*StreamItem) ClearError ¶ added in v0.18.0
func (x *StreamItem) ClearError()
func (*StreamItem) ClearJson ¶ added in v0.18.0
func (x *StreamItem) ClearJson()
func (*StreamItem) ClearProto ¶ added in v0.18.0
func (x *StreamItem) ClearProto()
func (*StreamItem) GetCelContent ¶ added in v0.18.0
func (x *StreamItem) GetCelContent() string
func (*StreamItem) GetDelay ¶ added in v0.18.0
func (x *StreamItem) GetDelay() *durationpb.Duration
func (*StreamItem) GetError ¶ added in v0.18.0
func (x *StreamItem) GetError() *Error
func (*StreamItem) GetJson ¶ added in v0.18.0
func (x *StreamItem) GetJson() string
func (*StreamItem) GetProto ¶ added in v0.18.0
func (x *StreamItem) GetProto() []byte
func (*StreamItem) HasCelContent ¶ added in v0.18.0
func (x *StreamItem) HasCelContent() bool
func (*StreamItem) HasContent ¶ added in v0.18.0
func (x *StreamItem) HasContent() bool
func (*StreamItem) HasDelay ¶ added in v0.18.0
func (x *StreamItem) HasDelay() bool
func (*StreamItem) HasError ¶ added in v0.18.0
func (x *StreamItem) HasError() bool
func (*StreamItem) HasJson ¶ added in v0.18.0
func (x *StreamItem) HasJson() bool
func (*StreamItem) HasProto ¶ added in v0.18.0
func (x *StreamItem) HasProto() bool
func (*StreamItem) ProtoMessage ¶ added in v0.18.0
func (*StreamItem) ProtoMessage()
func (*StreamItem) ProtoReflect ¶ added in v0.18.0
func (x *StreamItem) ProtoReflect() protoreflect.Message
func (*StreamItem) Reset ¶ added in v0.18.0
func (x *StreamItem) Reset()
func (*StreamItem) SetCelContent ¶ added in v0.18.0
func (x *StreamItem) SetCelContent(v string)
func (*StreamItem) SetDelay ¶ added in v0.18.0
func (x *StreamItem) SetDelay(v *durationpb.Duration)
func (*StreamItem) SetError ¶ added in v0.18.0
func (x *StreamItem) SetError(v *Error)
func (*StreamItem) SetJson ¶ added in v0.18.0
func (x *StreamItem) SetJson(v string)
func (*StreamItem) SetProto ¶ added in v0.18.0
func (x *StreamItem) SetProto(v []byte)
func (*StreamItem) String ¶ added in v0.18.0
func (x *StreamItem) String() string
func (*StreamItem) WhichContent ¶ added in v0.18.0
func (x *StreamItem) WhichContent() case_StreamItem_Content
type StreamItem_builder ¶ added in v0.18.0
type StreamItem_builder struct {
// Fields of oneof xxx_hidden_Content:
Proto []byte
Json *string
Error *Error
// -- end of xxx_hidden_Content
CelContent *string
Delay *durationpb.Duration
// contains filtered or unexported fields
}
func (StreamItem_builder) Build ¶ added in v0.18.0
func (b0 StreamItem_builder) Build() *StreamItem
type Stream_builder ¶ added in v0.18.0
type Stream_builder struct {
Items []*StreamItem
Repeated *bool
DoneAfter *durationpb.Duration
// contains filtered or unexported fields
}
func (Stream_builder) Build ¶ added in v0.18.0
func (b0 Stream_builder) Build() *Stream
type Stub ¶
type Stub struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*Stub) ClearActiveIf ¶
func (x *Stub) ClearActiveIf()
func (*Stub) ClearCelContent ¶
func (x *Stub) ClearCelContent()
func (*Stub) ClearContent ¶
func (x *Stub) ClearContent()
func (*Stub) ClearError ¶
func (x *Stub) ClearError()
func (*Stub) ClearPriority ¶
func (x *Stub) ClearPriority()
func (*Stub) ClearProto ¶
func (x *Stub) ClearProto()
func (*Stub) ClearStream ¶ added in v0.18.0
func (x *Stub) ClearStream()
func (*Stub) GetActiveIf ¶
func (*Stub) GetCelContent ¶
func (*Stub) GetPriority ¶
func (*Stub) HasActiveIf ¶
func (*Stub) HasCelContent ¶
func (*Stub) HasContent ¶
func (*Stub) HasPriority ¶
func (*Stub) ProtoMessage ¶
func (*Stub) ProtoMessage()
func (*Stub) ProtoReflect ¶
func (x *Stub) ProtoReflect() protoreflect.Message
func (*Stub) SetActiveIf ¶
func (*Stub) SetCelContent ¶
func (*Stub) SetPriority ¶
func (*Stub) WhichContent ¶
func (x *Stub) WhichContent() case_Stub_Content
type StubRef ¶
type StubRef struct {
XXX_raceDetectHookData protoimpl.RaceDetectHookData
XXX_presence [1]uint32
// contains filtered or unexported fields
}
func (*StubRef) ClearTarget ¶
func (x *StubRef) ClearTarget()
func (*StubRef) ProtoMessage ¶
func (*StubRef) ProtoMessage()
func (*StubRef) ProtoReflect ¶
func (x *StubRef) ProtoReflect() protoreflect.Message
type StubRef_builder ¶
func (StubRef_builder) Build ¶
func (b0 StubRef_builder) Build() *StubRef
type Stub_builder ¶
type Stub_builder struct {
Ref *StubRef
// Fields of oneof xxx_hidden_Content:
Proto []byte
Json *string
Error *Error
// -- end of xxx_hidden_Content
// CEL rule to decide if this stub should be used for a given request.
ActiveIf *string
// Similar to the json attribute but is a CEL expression that returns the result.
CelContent *string
Priority *int32
Stream *Stream
// contains filtered or unexported fields
}
func (Stub_builder) Build ¶
func (b0 Stub_builder) Build() *Stub
Click to show internal directories.
Click to hide internal directories.